/***************************************************************************
 *   Name:      Music_Format.h                                             *
 *   Purpose:   Defines Music Format support                               *
 *   Copyright (C) 2008 by Jackie Team                                     *
 *   jackie.team@gmail.com                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MUSIC_FORMAT_H
#define MUSIC_FORMAT_H
#include <fileref.h>
#include <tag.h>
#include <id3v1tag.h>
#include <id3v2tag.h>
#include <mpegfile.h>
#include <fileref.h>
#ifdef USE_MP4
    #include <mp4file.h>
#endif
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

/**
 * Abstract class MusicFormat
 * Allows to create a derived class for each format
 */
class MusicFormat{
    protected:
        TagLib::MPEG::File file;
    public:
        MusicFormat(wxString f);
        virtual ~MusicFormat();
        virtual wxString getArtist();
        virtual wxString getTitle();
        virtual wxString getAlbum();
        virtual wxString getGenre();
        virtual wxString getTrack();
        virtual wxString getYear();
        virtual wxString getLength();
};

class MusicFormatID3V1:public MusicFormat{
    public:
        MusicFormatID3V1(wxString f);
        ~MusicFormatID3V1();
        wxString getArtist();
        wxString getTitle();
        wxString getAlbum();
        wxString getGenre();
        wxString getTrack();
        wxString getYear();
        wxString getLength();
};

class MusicFormatID3V2:public MusicFormat{
    public:
        MusicFormatID3V2(wxString f);
        ~MusicFormatID3V2();
        wxString getArtist();
        wxString getTitle();
        wxString getAlbum();
        wxString getGenre();
        wxString getTrack();
        wxString getYear();
        wxString getLength();
};

class MusicFormatOGG:public MusicFormat{
    public:
        MusicFormatOGG(wxString f);
        ~MusicFormatOGG();
        wxString getArtist();
        wxString getTitle();
        wxString getAlbum();
        wxString getGenre();
        wxString getTrack();
        wxString getYear();
        wxString getLength();
};

class MusicFormatFLAC:public MusicFormatOGG{
    public:
        MusicFormatFLAC(wxString f);
        ~MusicFormatFLAC();
};

#ifdef USE_MP4
class MusicFormatMP4:public MusicFormat{
    public:
        MusicFormatMP4(wxString f);
        ~MusicFormatMP4();
        wxString getArtist();
        wxString getTitle();
        wxString getAlbum();
        wxString getGenre();
        wxString getTrack();
        wxString getYear();
        wxString getLength();
};
#endif

#endif
